@@ -52,6 +52,19 @@ sub getAccessPointByID
 	}
 }
 
+sub getAccessPointByMACAddress
+{
+        my ($self, $macaddress) = @_;
+
+        if (defined($macaddress))
+        {
+                foreach my $ap ($self->getAccessPoints())
+                {
+                        if ($ap->mac eq $macaddress) { return $ap };
+                }
+        }
+}
+
 sub getAccessPoints
 {
 	my ($self) = @_;
