@@ -37,9 +37,23 @@ sub new
 
 sub toString
 {
-        my ($self) = @_;
+	my ($self) = @_;
 
-        return "mac=" . $self->mac . ", department=" . $self->department . ", vlanId=" . $self->vlanId . ", vlanCode=" . $self->vlanCode . ", vlanName=" . $self->vlanName . ", hostname=" . $self->hostname . ", username=" . $self->username;
+	return "mac=" . $self->mac . ", department=" . $self->department . ", vlanId=" . $self->vlanId . ", vlanCode=" . $self->vlanCode . ", vlanName=" . $self->vlanName . ", hostname=" . $self->hostname . ", username=" . $self->username;
+}
+
+sub toPipedString
+{
+	my ($self, $prefix) = @_;
+
+	my $mac = $self->mac;							$mac =~ s/..\K(?=.)/-/g;
+	my $department = $self->department;
+	my $vlanId = $self->vlanId;
+	my $hostname = $self->hostname;
+	my $username = $self->username;
+	my $description = $self->description;
+
+	return (defined($prefix) ? $prefix . " " : "") . "$mac|$department|$vlanId|$hostname|$username|$description";
 }
 
 use overload '""' => \&toString;
