@@ -12,6 +12,7 @@ use UvT::NOC::Util::FileUtil;
 
 use UvT::NOC::InfraStructure::HostList;
 use UvT::NOC::InfraStructure::SwitchList;
+use UvT::NOC::InfraStructure::BuildingList;
 use UvT::NOC::Tracking::UserTrackingData;
 use UvT::NOC::Tracking::Network;
 use UvT::NOC::Tracking::Vlan;
@@ -25,7 +26,7 @@ use Data::Dumper;
 
 use Exporter qw(import);
 
-our @EXPORT = qw(readHostsFile readInfra readUserTrackingData readIntreg readWMBReg);
+our @EXPORT = qw(readHostsFile readInfra readUserTrackingData readIntreg readWMBReg readOutlets readPIWiredClientDetails readPIWirelessClientDetails);
 our @EXPORT_OK = @EXPORT;
 
 # Functienaam : readHostsFile
@@ -479,4 +480,209 @@ sub readWMBReg
 	return $regList;
 }
 
+sub readOutlets
+{
+	my $filename = shift;
+
+	my $data = stringFromFile($filename);
+
+	my $buildingList = new UvT::NOC::InfraStructure::BuildingList();
+
+	foreach my $line (split('\n', $data))
+	{
+		if ($line =~ /([^|]*\|){2}/)
+		{
+			eval
+			{
+				my @data = split(/\|/, trim($line));
+				my $roomOutlet = trim($data[0]);
+				
+				$roomOutlet =~ m/^.*?\ (.*)\.(.*?)$/;
+				my $room = $1;
+				my $rOutlet = $2;
+				if (!defined($room) || !defined($rOutlet))
+				{
+					die "Error parsing room field : $roomOutlet";
+				}
+
+				my $erRoomOutlet = trim($data[1]);
+				$erRoomOutlet =~ m/^(.*?)\ (.*)\.(.*?)$/;
+				my $building = $1;
+				my $erRoom = $2;
+				my $erOutlet = $3;
+				if (!defined($building) || !defined($erRoom) || !defined($erOutlet))
+				{
+					die "Error parsing distribution room field : $erRoomOutlet";
+				}
+
+				#unless ($rOutlet eq $erOutlet)
+				#{
+				#	die "Outlet mismatch : $roomOutlet $erRoomOutlet";
+				#}
+
+				# als gebouw niet bestaat -> toevoegen
+				unless ($buildingList->hasBuilding($building))
+				{
+					my $newBuilding = new UvT::NOC::InfraStructure::Building($building);
+					$buildingList->addBuilding($newBuilding);
+				}
+
+				# gebouw bestaat -> verdeelruimte toevoegen als deze niet bestaat
+				unless ($buildingList->getBuilding($building)->hasEquipmentRoom($erRoom))
+				{
+					my $newEquipmentRoom = new UvT::NOC::InfraStructure::EquipmentRoom($erRoom);
+					$buildingList->getBuilding($building)->addEquipmentRoom($newEquipmentRoom);
+				}
+
+				my $newOutlet = new UvT::NOC::InfraStructure::Outlet($room, $erOutlet);
+				unless ($buildingList->getBuilding($building)->getEquipmentRoom($erRoom)->hasOutlet($newOutlet))
+				{
+					$buildingList->getBuilding($building)->getEquipmentRoom($erRoom)->addOutlet($newOutlet);
+				}
+				else
+				{
+					die "Duplicate outlet found : $erRoomOutlet";
+				}
+
+			};
+			if ($@)
+			{
+					warn "Error reading line : $@";
+			}
+		}
+	}
+
+    return $buildingList;
+}
+
+
+# Functienaam : readPIWiredClientDetails
+#
+# Parameters : (2x)
+#		1) de UserTracking data structure waaraan de ingelezen gegevens worden toegevoegd
+#       2) de locatie van de file met de wired client details van prime infrastructure
+#
+# Return : (1x)
+#       1) een data structure met de usertracking-gegevens
+#
+# Omschrijving :
+#       Functie om wired client details uit de prime infrastructure xml file uit te lezen en de gegevens toe te voegen aan de meegekregen UserTrackingData datastructure welke wordt geretourneerd
+
+
+sub readPIWiredClientDetails
+{
+	my $trackingData = shift;
+        my $filename = shift;
+
+        my $parser = XML::LibXML->new();
+        my $doc    = $parser->parse_string(stringFromFile($filename));
+
+        foreach my $utdata ($doc->findnodes('/queryResponse/entity/clientDetailsDTO'))
+        {
+                my $network = "UvT Wired";
+
+                # als het netwerk nog niet bestaat in de tracking data structure -> toevoegen
+                unless ($trackingData->hasNetwork($network))
+                {
+                        my $newNetwork = new UvT::NOC::Tracking::Network($network);
+                        $trackingData->addNetwork($newNetwork);
+                }
+
+                my $vlan = trim($utdata->findnodes('./vlan')->string_value);
+
+                # als het vlan niet bestaat in het betreffende netwerk object -> toevoegen
+                unless ($trackingData->getNetworkByName($network)->hasVlan($vlan))
+                {
+                        my $newVlan = new UvT::NOC::Tracking::Vlan($vlan);
+                        $trackingData->getNetworkByName($network)->addVlan($newVlan);
+                }
+
+                my $mac = trim($utdata->findnodes('./macAddress')->string_value);
+                $mac =~ s/[^a-zA-Z0-9 ]//g;
+
+                # als het mac address niet bestaat in het betreffende vlan object -> toevoegen
+                unless ($trackingData->getNetworkByName($network)->getVlanById($vlan)->hasMacAddress($mac))
+                {
+                        my $newMac = new UvT::NOC::Tracking::MACAddress($mac);
+                        $trackingData->getNetworkByName($network)->getVlanById($vlan)->addMacAddress($newMac);
+                }
+
+                # op dit punt bestaat het betreffende mac adres in de het trackingData object -> TrackingData hieraan toevoegen
+                my $switchIp = trim($utdata->findnodes('./deviceIpAddress')->string_value);
+                my $switchPort = trim($utdata->findnodes('./ifDescr')->string_value);
+                my $timestamp = trim($utdata->findnodes('./updateTime')->string_value);
+                my $hostIp = trim($utdata->findnodes('./ipAddress')->string_value);
+
+                my $tData = new UvT::NOC::Tracking::TrackingData($switchIp, $switchPort, $timestamp, $hostIp);
+                $trackingData->getNetworkByName($network)->getVlanById($vlan)->getMacAddress($mac)->addTrackingData($tData);
+        }
+
+        return $trackingData;
+}
+
+
+# Functienaam : readPIWirelessClientDetails
+#
+# Parameters : (2x)
+#		1) de UserTracking data structure waaraan de ingelezen gegevens worden toegevoegd
+#       2) de locatie van de file met de wireless client details van prime infrastructure
+#
+# Return : (1x)
+#       1) een data structure met de usertracking-gegevens
+#
+# Omschrijving :
+#       Functie om wireless client details uit de prime infrastructure xml file uit te lezen en de gegevens toe te voegen aan de meegekregen UserTrackingData datastructure welke wordt geretourneerd
+
+
+sub readPIWirelessClientDetails
+{
+		my $trackingData = shift;
+        my $filename = shift;
+
+        my $parser = XML::LibXML->new();
+        my $doc    = $parser->parse_string(stringFromFile($filename));
+
+        foreach my $utdata ($doc->findnodes('/queryResponse/entity/clientDetailsDTO'))
+        {
+                my $network = "UvT Wireless";
+
+                # als het netwerk nog niet bestaat in de tracking data structure -> toevoegen
+                unless ($trackingData->hasNetwork($network))
+                {
+                        my $newNetwork = new UvT::NOC::Tracking::Network($network);
+                        $trackingData->addNetwork($newNetwork);
+                }
+
+                my $vlan = trim($utdata->findnodes('./vlan')->string_value);
+
+                # als het vlan niet bestaat in het betreffende netwerk object -> toevoegen
+                unless ($trackingData->getNetworkByName($network)->hasVlan($vlan))
+                {
+                        my $newVlan = new UvT::NOC::Tracking::Vlan($vlan);
+                        $trackingData->getNetworkByName($network)->addVlan($newVlan);
+                }
+
+                my $mac = trim($utdata->findnodes('./macAddress')->string_value);
+                $mac =~ s/[^a-zA-Z0-9 ]//g;
+
+                # als het mac address niet bestaat in het betreffende vlan object -> toevoegen
+                unless ($trackingData->getNetworkByName($network)->getVlanById($vlan)->hasMacAddress($mac))
+                {
+                        my $newMac = new UvT::NOC::Tracking::MACAddress($mac);
+                        $trackingData->getNetworkByName($network)->getVlanById($vlan)->addMacAddress($newMac);
+                }
+
+                # op dit punt bestaat het betreffende mac adres in de het trackingData object -> TrackingData hieraan toevoegen
+                my $switchIp = trim($utdata->findnodes('./deviceIpAddress')->string_value);
+                my $switchPort = trim($utdata->findnodes('./apName')->string_value);
+                my $timestamp = trim($utdata->findnodes('./updateTime')->string_value);
+                my $hostIp = trim($utdata->findnodes('./ipAddress')->string_value);
+
+                my $tData = new UvT::NOC::Tracking::TrackingData($switchIp, $switchPort, $timestamp, $hostIp);
+                $trackingData->getNetworkByName($network)->getVlanById($vlan)->getMacAddress($mac)->addTrackingData($tData);
+        }
+
+        return $trackingData;
+}
+
 1;
